<?php
/*
Plugin Name: WP Time Widget
Plugin URI: http://wp-time.com/create-custom-wordpress-widget-with-options/
Description: Create a Custom WordPress Widget with Options and Settings.
Version: 1.0.0
Author: Qassim Hassan
Author URI: http://wp-time.com/qassim-hassan/
License: GPLv2 or later
*/


defined( 'ABSPATH' ) or die( 'Silence is golden' );


// A simple widget
class MyClassName extends WP_Widget {
    function MyClassName() {
        parent::__construct( false, 'Your Widget Name', array('description' => 'Your widget description...') );
    }

    function widget( $args, $instance ) {
        echo $args['before_widget'];
        echo "Hello World";
        echo $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
    }

    function form( $instance ) {
    }
}
add_action('widgets_init', create_function('', 'return register_widget("MyClassName");') );


///////////////////////////////////////////////////////////////////////////////////////////////////////////////


// A Custom Widget with Options
class MyCustomWidgetClassName extends WP_Widget {
    function MyCustomWidgetClassName() {
        parent::__construct( false, 'My Custom Widget', array('description' => 'A custom WordPress widget example.') );
    }


    function widget( $args, $instance ) {
        $title = $instance['title']; // get title option value.
        $text_op = $instance['text_op']; // get text input option value.
        $textarea_op = $instance['textarea_op']; // get textarea option value.
        $checkbox_op = $instance['checkbox_op']; // get checkbox value, if the value is 1 (checked) do something.
        $radio_op = $instance['radio_op']; // get radio option value.
        $select_op = $instance['select_op']; // get select option value.
        ?>
            
            <?php echo $args['before_widget']; // open widget wrap, Read about "before and after widget": https://codex.wordpress.org/Function_Reference/register_sidebar ?>

                <?php
                    if ( !empty($title) ){ // if have title will be display it inside your theme widget title wrap
                        echo $args['before_title']; // open widget title wrap, for example if your theme widget title wrap is <h3>, will be display it automatically.
                        echo $title;
                        echo $args['after_title']; // close widget title wrap, for example </h3>. Read about "before and after title": https://codex.wordpress.org/Function_Reference/register_sidebar
                    }
                ?>

                <?php
                    if( !empty($text_op) ){ // if have value in text input option
                        echo "<p>". $text_op . "</p>";
                    }

                    if( !empty($textarea_op) ){ // if have value or HTML tags in textarea option
                        echo $textarea_op;
                    }
                ?>

                <?php
                    if( $checkbox_op ){ // if the checkbox is checked, do something. | if not working: use !empty($checkbox_op)
                        echo "<p>". get_bloginfo('name') . "</p>";
                    }
                ?>

                <?php
                    if( $radio_op == 'yes' ){ // if radio option value is 'yes'
                        echo "<p>Yes! I like WordPress.</p>";
                    }
                    else{ // if the value is not 'yes'
                        if( $radio_op == 'no' ){ // if radio option value is 'no'
                            echo "<p>No! I don't like WordPress.</p>";
                        }
                    }
                ?>

                <?php
                    if( $select_op == 'single' ){ // if select option value is 'single'
                        echo "<p>I'm single.</p>";
                    }
                    else{ // if the value is not 'single'
                        if( $select_op == 'married' ){ // if select option value is 'married'
                            echo "<p>I'm married.</p>";
                        }
                    }
                ?>
            
            <?php echo $args['after_widget']; // close widget wrap ?>

        <?php
    } // widget()


    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['text_op'] = sanitize_text_field($new_instance['text_op']);
        $instance['textarea_op'] = wp_kses_post( stripslashes($new_instance['textarea_op']) ); // allow HTML tags, Read about wp_kses_post() https://codex.wordpress.org/Function_Reference/wp_kses_post
        $instance['checkbox_op'] = $new_instance['checkbox_op'];
        $instance['radio_op'] = $new_instance['radio_op'];
        $instance['select_op'] = $new_instance['select_op'];
        return $instance;
    }//update()


    function form( $instance ) {
        $defaults = array( // default value of options.
                        'title'         => '', // default widget title is empty, you can change it.
                        'text_op'       => '', // default value is empty, you can change it.
                        'textarea_op'   => '<p>Hello Baby!</p>', // default value is 'Hello Baby!', if you want default value to be empty remove the value, and you can use HTML tags.
                        'checkbox_op'   => '', // default is not "checked", if you want default value to be "checked" enter value '1'
                        'radio_op'      => 'yes', // default radio value is 'yes'
                        'select_op'     => 'single' // default select value is 'single'
                    );
        
        $instance = wp_parse_args( (array) $instance, $defaults ); // Read about wp_parse_args() https://codex.wordpress.org/Function_Reference/wp_parse_args

        // Read about data validation: https://codex.wordpress.org/Data_Validation
        $title = sanitize_text_field($instance['title']);
        $text_op = sanitize_text_field($instance['text_op']);
        $textarea_op = esc_textarea($instance['textarea_op']);
        $checkbox_op = $instance['checkbox_op']; // Read about checked() https://codex.wordpress.org/Function_Reference/checked
        $radio_op = $instance['radio_op']; // Read about checked() https://codex.wordpress.org/Function_Reference/checked
        $select_op = $instance['select_op']; // Read about selected() https://codex.wordpress.org/Function_Reference/selected
        ?>
            <p>
                <label for="<?php echo $this->get_field_id('title'); ?>">Title:</label> 
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('text_op'); ?>">Text Input Option:</label> 
                <input class="widefat" id="<?php echo $this->get_field_id('text_op'); ?>" name="<?php echo $this->get_field_name('text_op'); ?>" type="text" value="<?php echo esc_attr($text_op); ?>" />
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('textarea_op'); ?>">Textarea Option</label> 
                <textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('textarea_op'); ?>" name="<?php echo $this->get_field_name('textarea_op'); ?>"><?php echo $textarea_op; ?></textarea>
            </p>

            <p>
                <input id="<?php echo $this->get_field_id('checkbox_op'); ?>" name="<?php echo $this->get_field_name('checkbox_op'); ?>" type="checkbox" value="1" <?php checked($checkbox_op, 1); ?>/>
                <label for="<?php echo $this->get_field_id('checkbox_op'); ?>">Display blog name.</label>
            </p>

            <p>
                <label>Do you like WordPress?</label><br>
                <label for="<?php echo $this->get_field_id('radio_op') . 'yes'; ?>"><input id="<?php echo $this->get_field_id('radio_op') . 'yes'; ?>" name="<?php echo $this->get_field_name('radio_op'); ?>" type="radio" value="yes" <?php checked($radio_op, 'yes'); ?>/>Yes.</label><br>
                <label for="<?php echo $this->get_field_id('radio_op') . 'no'; ?>"><input id="<?php echo $this->get_field_id('radio_op') . 'no'; ?>" name="<?php echo $this->get_field_name('radio_op'); ?>" type="radio" value="no" <?php checked($radio_op, 'no'); ?>/>No.</label>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('select_op'); ?>">Are you married?</label>
                <select name="<?php echo $this->get_field_name('select_op'); ?>" id="<?php echo $this->get_field_id('select_op'); ?>">
                    <option value="single" <?php selected( $select_op, 'single' ); ?>>Single</option>
                    <option value="married" <?php selected( $select_op, 'married' ); ?>>Married</option>
                </select>
            </p>
        <?php
        
    }//form()
}
add_action('widgets_init', create_function('', 'return register_widget("MyCustomWidgetClassName");') );


///////////////////////////////////////////////////////////////////////////////////////////////////////////////


// A Simple Custom Widget with 1 option to display some image
class MySimpleWidgetClassName extends WP_Widget {
    function MySimpleWidgetClassName() {
        parent::__construct( false, 'My Simple Widget', array('description' => 'A Simple Widget.') );
    }


    function widget( $args, $instance ) {
        $title = $instance['title']; // get title option value
        $image_link = $instance['image_link']; // get image link option value.
        ?>
            
            <?php echo $args['before_widget']; ?>

                <?php
                    if ( !empty($title) ){ // if have title will be display it
                        echo $args['before_title'] . $title . $args['after_title'];
                    }

                    if( !empty($image_link) ){ // if have value in image link option
                        echo '<img src="'.esc_url($image_link).'">';
                    }
                ?>
            
            <?php echo $args['after_widget']; ?>

        <?php
    } //widget()


    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['image_link'] = sanitize_text_field($new_instance['image_link']);
        return $instance;
    }//update()


    function form( $instance ) {
        $defaults = array(
                        'title' => '',
                        'image_link' => ''
                    );
        
        $instance = wp_parse_args( (array) $instance, $defaults );

        $title = sanitize_text_field($instance['title']);
        $image_link = sanitize_text_field($instance['image_link']);
        ?>
            <p>
                <label for="<?php echo $this->get_field_id('title'); ?>">Title:</label> 
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('image_link'); ?>">Image Link:</label> 
                <input class="widefat" id="<?php echo $this->get_field_id('image_link'); ?>" name="<?php echo $this->get_field_name('image_link'); ?>" type="text" value="<?php echo esc_attr($image_link); ?>" />
            </p>
        <?php
        
    }//form()
}
add_action('widgets_init', create_function('', 'return register_widget("MySimpleWidgetClassName");') );